@@ -45,9 +45,9 @@ GtkTreeModel * gyrus_admin_acl_treemodel_new (void);
 
 void gyrus_admin_on_button_connect_clicked (GtkButton *button,
 					    gpointer user_data);
-void
+/*void
 gyrus_admin_on_entry_pass_activate (GtkEntry *entry,
-				    gpointer user_data);
+gpointer user_data);*/
 void
 gyrus_admin_on_treeview_users_cursor_changed (GtkTreeView *treeview,
 					      gpointer *data);
@@ -142,10 +142,10 @@ gyrus_admin_init_get_widgets (GyrusAdmin *admin)
 	priv->label_acl    = glade_xml_get_widget (xml_page, "label_acl");
 	priv->scrolled_acl = glade_xml_get_widget (xml_page, "scrolled_acl");
 	
-	priv->entry_host     = glade_xml_get_widget (xml_page, "entry_host");
-	priv->entry_admin    = glade_xml_get_widget (xml_page, "entry_admin");
-	priv->entry_port     = glade_xml_get_widget (xml_page, "entry_port");
-	priv->entry_pass     = glade_xml_get_widget (xml_page, "entry_pass");
+	priv->label_host     = glade_xml_get_widget (xml_page, "label_host");
+	priv->label_user     = glade_xml_get_widget (xml_page, "label_user");
+	priv->label_port     = glade_xml_get_widget (xml_page, "label_port");
+/*	priv->entry_pass     = glade_xml_get_widget (xml_page, "entry_pass"); */
 	priv->button_connect = glade_xml_get_widget (xml_page, "button_connect");
 
 	priv->label_mailbox_owner =
@@ -185,10 +185,10 @@ gyrus_admin_init_connect_signals (GyrusAdmin *admin)
 			  G_CALLBACK (gyrus_admin_on_button_connect_clicked),
 			  admin);
 
-	g_signal_connect (G_OBJECT (admin->priv->entry_pass), "activate",
+/*	g_signal_connect (G_OBJECT (admin->priv->entry_pass), "activate",
 			  G_CALLBACK (gyrus_admin_on_entry_pass_activate),
 			  admin->priv->button_connect);
-	
+*/
 	g_signal_connect (G_OBJECT (admin->priv->button_quota_apply),
 			  "clicked",
 			  G_CALLBACK (gyrus_admin_mailbox_on_button_quota_apply_clicked),
@@ -743,40 +743,45 @@ void
 gyrus_admin_pre_login (GyrusAdmin *admin)
 {
 	GyrusAdminLoginError error;
-	GtkEntry *entry = GTK_ENTRY (admin->priv->entry_pass);
+	gboolean keep_asking = TRUE;
 	
-	if (admin->priv->session->passwd) {
-		g_free (admin->priv->session->passwd);
-		admin->priv->session->passwd = NULL;
-	}
-	admin->priv->session->passwd =
-		g_strdup (gtk_entry_get_text (entry));
-	
-	if (strlen (admin->priv->session->passwd) == 0) {
-		gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR,
-					   _("Enter your password"));
-			return;
-	}
-	
-	error = gyrus_admin_login (admin);
-	
-	if (error == GYRUS_ADMIN_LOGIN_NO_PASS) {
-		gyrus_admin_logout (admin);
-		gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR,
-					   _("Enter your password"));
-	}
-	else if (error == GYRUS_ADMIN_LOGIN_BAD_LOGIN) {
-		gyrus_admin_logout (admin);
-		gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR,
-					   _("Incorrect login/password"));
-	}
-	else if (error == GYRUS_ADMIN_LOGIN_NO_HOST) {
-		/* do something useful here */
-	}
-	else {
-		gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
-				      GTK_STOCK_STOP);
-		gyrus_admin_post_login (admin);
+	while (keep_asking) {
+		if (admin->priv->session->passwd) {
+			g_free (admin->priv->session->passwd);
+			admin->priv->session->passwd = NULL;
+		}
+		
+		admin->priv->session->passwd = gyrus_dialog_password_new ();
+		if (admin->priv->session->passwd == NULL)
+			/* user canceled */
+			keep_asking = FALSE;
+		else {
+			error = gyrus_admin_login (admin);
+			
+			if (error == GYRUS_ADMIN_LOGIN_NO_PASS) {
+				gyrus_admin_logout (admin);
+				gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR,
+							   _("Unable to connect with empty "
+							     "passwords. Please introduce your "
+							     "password."));
+			}
+			else if (error == GYRUS_ADMIN_LOGIN_BAD_LOGIN) {
+				gyrus_admin_logout (admin);
+				gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR,
+							   _("Incorrect login/password"));
+			}
+			else if (error == GYRUS_ADMIN_LOGIN_NO_HOST) {
+				/* do something useful here */
+			}
+			else {
+				gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
+						      GTK_STOCK_STOP);
+				gyrus_admin_post_login (admin);
+				/* correctly logged in */
+				keep_asking = FALSE;
+				return;
+			}
+		}
 	}
 }
 
@@ -938,11 +943,11 @@ gyrus_admin_load_session_info (GyrusAdmin *admin, GyrusSession *session)
 	admin->priv->session->port = session->port;
 
 	/* set the interface */
-	gtk_entry_set_text (GTK_ENTRY (admin->priv->entry_host),
+	gtk_label_set_label (GTK_LABEL (admin->priv->label_host),
 			    session->host);
-	gtk_entry_set_text (GTK_ENTRY (admin->priv->entry_port), port);
-	gtk_entry_set_text (GTK_ENTRY (admin->priv->entry_admin),
-			    session->user);
+	gtk_label_set_label (GTK_LABEL (admin->priv->label_port), port);
+	gtk_label_set_label (GTK_LABEL (admin->priv->label_user),
+			     session->user);
 
 	g_free (port);
 }
@@ -959,7 +964,7 @@ gyrus_admin_new (GyrusSession *session)
 	GyrusAdmin *admin;
 	admin = g_object_new (GYRUS_TYPE_ADMIN, NULL);
 	gyrus_admin_load_session_info (GYRUS_ADMIN (admin), session);
-	gtk_widget_grab_focus (GTK_WIDGET (admin->priv->entry_pass));
+/*	gtk_widget_grab_focus (GTK_WIDGET (admin->priv->entry_pass));*/
 	return GTK_WIDGET (admin);
 }
 
@@ -982,7 +987,7 @@ gyrus_admin_on_button_connect_clicked (GtkButton *button,
 		gyrus_admin_pre_login (admin);
 	}
 }
-
+/*
 void
 gyrus_admin_on_entry_pass_activate (GtkEntry *entry,
 				    gpointer user_data)
@@ -990,7 +995,7 @@ gyrus_admin_on_entry_pass_activate (GtkEntry *entry,
 	GtkButton *button = GTK_BUTTON (user_data);
 	gtk_button_clicked (button);
 }
-
+*/
 void
 gyrus_admin_on_acl_selection_changed (GtkTreeSelection *selection,
 				      gpointer user_data)
