@@ -33,5 +33,10 @@ gyrus_common_show_message (GtkWindow *parent, GtkMessageType type,
 gboolean
 gtk_entry_has_text (GtkEntry *entry);
 
+/**
+   Asks the user for a password. Returns a newly allocated string with the
+   password, or NULL if the user cancel the login.
+*/
+gchar *gyrus_dialog_password_new (void);
 
 #endif /* GYRUS_COMMON_H */
